@@ -1,6 +1,6 @@
 #ifndef GCC_TM_H
 #define GCC_TM_H
-#define TARGET_CPU_DEFAULT (TARGET_CPU_generic)
+#define TARGET_CPU_DEFAULT ("arm10tdmi")
 #ifndef LIBC_GLIBC
 # define LIBC_GLIBC 1
 #endif
@@ -10,6 +10,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -19,6 +22,7 @@
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
+# include "config/vxworks-dummy.h"
 # include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
@@ -31,7 +35,6 @@
 # include "config/arm/bpabi.h"
 # include "config/arm/linux-eabi.h"
 # include "config/arm/aout.h"
-# include "config/vxworks-dummy.h"
 # include "config/arm/arm.h"
 # include "config/initfini-array.h"
 #endif
